@@ -34,7 +34,6 @@
 #include "callbacks.h"
 #include "interface.h"
 #include "proctable.h"
-#include "infoview.h"
 #include "procactions.h"
 #include "load-graph.h"
 #include "util.h"
@@ -159,7 +158,7 @@ static const char ui_info[] =
 static GtkWidget *
 create_proc_view (ProcData *procdata)
 {
-	GtkWidget *vbox1, *vbox2;
+	GtkWidget *vbox1;
 	GtkWidget *hbox1;
 	GtkWidget *scrolled;
 	GtkWidget *hbox2;
@@ -190,17 +189,9 @@ create_proc_view (ProcData *procdata)
 	
 	hbox2 = gtk_hbox_new (FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox1), hbox2, FALSE, FALSE, 0);
-
-	infoview_create (procdata);
-	gtk_box_pack_start (GTK_BOX (hbox2), procdata->infoview.expander, FALSE, FALSE, 0);
-	gtk_expander_set_expanded (GTK_EXPANDER(procdata->infoview.expander),
-				   procdata->config.show_more_info);
-	gtk_widget_show (procdata->infoview.expander);
 	
-	vbox2 = gtk_vbox_new (FALSE, 0);
-	gtk_box_pack_end (GTK_BOX (hbox2), vbox2, FALSE, FALSE, 0);
 	procdata->endprocessbutton = gtk_button_new_with_mnemonic (_("End _Process"));
-	gtk_box_pack_end (GTK_BOX (vbox2), procdata->endprocessbutton, FALSE, FALSE, 0);
+	gtk_box_pack_end (GTK_BOX (hbox2), procdata->endprocessbutton, FALSE, FALSE, 0);
 	g_signal_connect (G_OBJECT (procdata->endprocessbutton), "clicked",
 			  G_CALLBACK (cb_end_process_button_pressed), procdata);
 	
@@ -520,7 +511,7 @@ create_sys_view (ProcData *procdata)
 			    G_CALLBACK (cb_net_in_color_changed), procdata);
 	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 0, 1, 0, 0, 0, 0);
 
-	label = gtk_label_new (_("Receive:"));
+	label = gtk_label_new (_("Received:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, 0, 0, 0);
 
@@ -564,7 +555,7 @@ create_sys_view (ProcData *procdata)
 			    G_CALLBACK (cb_net_out_color_changed), procdata);
 	gtk_table_attach (GTK_TABLE (table), color_picker, 0, 1, 1, 2, 0, 0, 0, 0);
 
-	label = gtk_label_new (_("Send:"));
+	label = gtk_label_new (_("Sent:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 1, 2, 1, 2, GTK_FILL, 0, 0, 0);
 
@@ -821,8 +812,6 @@ update_sensitivity (ProcData *data, gboolean sensitivity)
 		gtk_widget_set_sensitive (data->endprocessbutton, sensitivity);
 	}
 
-	gtk_widget_set_sensitive (data->infoview.box, sensitivity);
-
 	action = gtk_action_group_get_action (data->action_group, "StopProcess");
 	gtk_action_set_sensitive (action, sensitivity);
 	action = gtk_action_group_get_action (data->action_group, "ContProcess");
