@@ -30,7 +30,6 @@ typedef struct _ProcData ProcData;
 #include <gconf/gconf-client.h>
 #include <glibtop/cpu.h>
 
-#include "infoview.h"
 #include "smooth_refresh.h"
 
 #include "load-graph.h"
@@ -55,7 +54,6 @@ struct _ProcConfig
 {
 	gint		width;
 	gint		height;
-        gboolean        show_more_info;
         gboolean	show_kill_warning;
         gboolean	show_hide_message;
         gboolean	show_tree;
@@ -94,11 +92,9 @@ struct _ProcInfo
 
 	guint64		cpu_time_last;
 
-	guint64		mem;
 	guint64		vmsize;
 	guint64		memres;
 	guint64		memshared;
-	guint64		memrss;
 	unsigned long	memxserver;
 
 	guint		pcpu; /* 0% - 100% */
@@ -123,7 +119,6 @@ struct _ProcData
 	GtkWidget	*loadavg;
 	GtkWidget	*endprocessbutton;
 	GtkWidget	*popup_menu;
-	Infoview	infoview;
 	GtkWidget	*disk_list;
 	ProcConfig	config;
 	LoadGraph	*cpu_graph;
