@@ -29,11 +29,9 @@ enum
 	COL_NAME = 0,
 	COL_USER,
 	COL_STATUS,
-	COL_MEM,
 	COL_VMSIZE,
 	COL_MEMRES,
 	COL_MEMSHARED,
-	COL_MEMRSS,
 	COL_MEMXSERVER,
 	COL_CPU,
 	COL_CPU_TIME,
